# ecc_rs.pyi

point = tuple[int, int]

def add(p1: point, p2: point) -> point:
    """
    Adds two points on the SM2 elliptic curve.

    Performs point addition on the SM2 curve defined by `sm2p256v1()`.

    Args:
        p1 (point): A tuple representing the x and y coordinates of the first point.
        p2 (point): A tuple representing the x and y coordinates of the second point.

    Raises:
        Panic: If the x or y coordinates of either point are not valid on the curve.

    Returns:
        point: A tuple representing the x and y coordinates of the resulting point after addition.

    Example:
        >>> p1 = (x1, y1)
        >>> p2 = (x2, y2)
        >>> result = add(p1, p2)
    """
    ...

def multiply(point: point, n: int) -> point:
    """
    multiply(point, n)

    Performs scalar multiplication of a point on the SM2 curve.

    performs the multiplication operation on the SM2 curve defined by `sm2p256v1()`.

    Args:
        point (point): representing the x and y coordinates of the point.
        n (int): representing the scalar to multiply the point by.

    Raises:
        Panic: If the x or y coordinates of the point are not less than the curve parameter `p`.

    Returns:
        point: representing the x and y coordinates of the result point.

    Example:
        >>> point = (g, g)
        >>> n = 10
        >>> result = multiply(point, n)
    """
    ...
